@@ -1,7 +1,7 @@
 #  Interface.pm
 #    - providing an object-oriented approach to interacting with GnuPG
 #
-#  Copyright (C) 2000 Frank J. Tobin <ftobin@uiuc.edu>
+#  Copyright (C) 2000 Frank J. Tobin <ftobin@cpan.org>
 #
 #  This module is free software; you can redistribute it and/or modify it
 #  under the same terms as Perl itself.
@@ -10,7 +10,7 @@
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #
-#  $Id: Interface.pm,v 1.34 2001/05/01 02:34:30 ftobin Exp $
+#  $Id: Interface.pm,v 1.42 2002/06/11 16:01:14 ftobin Exp $
 #
 
 package GnuPG::Interface;
@@ -28,7 +28,7 @@ use IO::Handle;
 use GnuPG::Options;
 use GnuPG::Handles;
 
-$VERSION = '0.30';
+$VERSION = '0.32';
 
 use Class::MethodMaker
   get_set         => [ qw( call  passphrase ) ],
@@ -116,18 +116,18 @@ sub fork_attach_exec( $% )
     
     my $handles = $args{handles} or croak 'no GnuPG::Handles passed';
     
-    my @commands = $args{commands}
-    ? @{ $args{commands} } : () or croak 'no gnupg command passed';
+    # deprecation support
+    $args{commands} ||= $args{gnupg_commands};
     
-    my @command_args = ();
-    if ( ref $args{command_args} )
-    {
-	@command_args = @{ $args{command_args} };
-    }
-    elsif ( $args{command_args } )
-    {
-	@command_args = ( $args{command_args} );
-    }
+    my @commands = ref $args{commands}
+      ? @{ $args{commands} } : ( $args{commands} )
+	or croak "no gnupg commands passed";
+    
+    # deprecation support
+    $args{command_args} ||= $args{gnupg_command_args};
+    
+    my @command_args = ref $args{command_args}
+      ? @{ $args{command_args} } : ( $args{command_args } || () );
     
     my %fhs;
     foreach my $fh_name ( qw( stdin stdout stderr status
@@ -357,10 +357,10 @@ sub my_fileno
 {
     no strict 'refs';
     my ( $fh ) = @_;
-    die "fh is undefined" unless defined $fh;
+    croak "fh is undefined" unless defined $fh;
     return $1 if $fh =~ /^=?(\d+)$/;   # is it a fd in itself?
     my $fileno = fileno $fh;
-    die "error determining fileno for $fh: $ERRNO" unless defined $fileno;
+    croak "error determining fileno for $fh: $ERRNO" unless defined $fileno;
     return $fileno;
 }
 
@@ -770,7 +770,7 @@ GnuPG::Interface - Perl interface to GnuPG
 			      homedir => '/home/foobar' );
 
   # Note you can set the recipients even if you aren't encrypting!
-  $gnupg->options->push_recipients( 'ftobin@uiuc.edu' );
+  $gnupg->options->push_recipients( 'ftobin@cpan.org' );
   $gnupg->options->meta_interactive( 0 );
 
   # how we create some handles to interact with GnuPG
@@ -781,7 +781,7 @@ GnuPG::Interface - Perl interface to GnuPG
 
   # Now we'll go about encrypting with the options already set
   my @plaintext = ( 'foobar' );
-  $gnupg->encrypt( handles => $handles );
+  my $pid = $gnupg->encrypt( handles => $handles );
   
   # Now we write to the input of GnuPG
   print $input @plaintext;
@@ -791,7 +791,7 @@ GnuPG::Interface - Perl interface to GnuPG
   my @ciphertext = <$output>;
   close $output;
 
-  wait;
+  waitpid $pid, 0;
 
 =head1 DESCRIPTION
 
@@ -938,7 +938,7 @@ is not defined, this channel of communication is never established with GnuPG,
 and so this information is not generated and does not come into play.
 If the B<passphrase> data member handle of the B<handles> object
 is not defined, but the the B<passphrase> data member handle of GnuPG::Interface
-object is, GnupG::Interface will handle passing this information into GnuPG
+object is, GnuPG::Interface will handle passing this information into GnuPG
 for the user as a convience.  Note that this will result in
 GnuPG::Interface storing the passphrase in memory, instead of having
 it simply 'pass-through' to GnuPG via a handle.
@@ -965,13 +965,14 @@ because of performance hits when listing information with signatures.
 =item test_default_key_passphrase()
 
 This method will return a true or false value, depending
-on whether GnupG reports a good passphrase was entered
+on whether GnuPG reports a good passphrase was entered
 while signing a short message using the values of
 the B<passphrase> data member, and the default
 key specified in the B<options> data member.
 
 =back
 
+
 =head1 Invoking GnuPG with a custom call
 
 GnuPG::Interface attempts to cover a lot of the commands
@@ -986,9 +987,9 @@ interface is provided, C<wrap_call>.
 Call GnuPG with a custom command.  The %args hash must contain
 at least the following keys:
 
-=over 6
+=over 4
 
-=item command
+=item commands
 
 The value of this key in the hash must be a reference to a a list of
 commands for GnuPG, such as C<[ qw( --encrypt --sign ) ]>.
@@ -1002,7 +1003,7 @@ must be a GnuPG::Handles object.
 
 The following keys are optional.
 
-=over 6
+=over 4
 
 =item command_args
 
@@ -1013,6 +1014,9 @@ keys to list in a key-listing.
 
 =back
 
+=back
+
+
 =head1 OBJECT DATA MEMBERS
 
 Note that these data members are interacted with via object methods
@@ -1049,12 +1053,12 @@ See L<GnuPG::Options> for more information.
 The following setup can be done before any of the following examples:
 
   use IO::Handle;
-  use GnupG::Interface;
+  use GnuPG::Interface;
 
   my @original_plaintext = ( "How do you doo?" );
-  my $passphrsae = "Three Little Pigs";
+  my $passphrase = "Three Little Pigs";
 
-  my $gnupg = GnupG::Interface->new();
+  my $gnupg = GnuPG::Interface->new();
 
   $gnupg->options->hash_init( armor    => 1,
                               recipients => [ 'ftobin@uiuc.edu',
@@ -1070,13 +1074,13 @@ The following setup can be done before any of the following examples:
   my ( $input, $output ) = ( IO::Handle->new(),
                              IO::Handle->new() );
 
-  my $handles = GnupG::Handles->new( stdin    => $input,
+  my $handles = GnuPG::Handles->new( stdin    => $input,
                                      stdout   => $output );
    
   # this sets up the communication
   # Note that the recipients were specified earlier
   # in the 'options' data member of the $gnupg object.
-  $gnupg->encrypt( handles => $handles );
+  my $pid = $gnupg->encrypt( handles => $handles );
 
   # this passes in the plaintext
   print $input @original_plaintext;
@@ -1087,7 +1091,7 @@ The following setup can be done before any of the following examples:
 
   my @ciphertext = <$output>;  # reading the output
 
-  wait;  # clean up the finished GnuPG process
+  waitpid $pid, 0;  # clean up the finished GnuPG process
 
 =head2 Signing
 
@@ -1097,7 +1101,7 @@ The following setup can be done before any of the following examples:
                                      IO::Handle->new(),
 				   );
 
-  my $handles = GnupG::Handles->new( stdin    => $input,
+  my $handles = GnuPG::Handles->new( stdin    => $input,
                                      stdout   => $output,
                                      stderr   => $error,
 				   );
@@ -1107,7 +1111,7 @@ The following setup can be done before any of the following examples:
   $gnupg->passphrase( $passphrase );
 
   # this sets up the communication
-  $gnupg->sign( handles => $handles );
+  my $pid = $gnupg->sign( handles => $handles );
 
   # this passes in the plaintext
   print $input @original_plaintext;
@@ -1122,7 +1126,7 @@ The following setup can be done before any of the following examples:
   close $output;
   close $error;
 
-  wait;  # clean up the finished GnuPG process
+  waitpid $pid, 0;  # clean up the finished GnuPG process
 
 =head2 Decryption
 
@@ -1137,7 +1141,7 @@ The following setup can be done before any of the following examples:
         IO::Handle->new(),
       );
 
-  my $handles = GnupG::Handles->new( stdin      => $input,
+  my $handles = GnuPG::Handles->new( stdin      => $input,
 				     stdout     => $output,
 				     stderr     => $error,
 				     passphrase => $passphrase_fh,
@@ -1150,7 +1154,7 @@ The following setup can be done before any of the following examples:
   my $cipher_file = IO::File->new( 'encrypted.gpg' );
    
   # this sets up the communication
-  $gnupg->decrypt( handles => $handles );
+  my $pid = $gnupg->decrypt( handles => $handles );
 
   # This passes in the passphrase
   print $passphrase_fd $passphrase;
@@ -1173,7 +1177,7 @@ The following setup can be done before any of the following examples:
   close $error;
   close $status_fh;
 
-  wait;  # clean up the finished GnuPG process
+  waitpid $pid, 0;  # clean up the finished GnuPG process
 
 =head2 Printing Keys
 
@@ -1186,10 +1190,10 @@ The following setup can be done before any of the following examples:
   # this time we need to specify something for
   # command_args because --list-public-keys takes
   # search ids as arguments
-  $gnupg->list_public_keys( handles      => $handles,
-                            command_args => [ @ids ]  );
+  my $pid = $gnupg->list_public_keys( handles      => $handles,
+                                      command_args => [ @ids ]  );
   
-   wait;
+   waitpid $pid, 0;
 
 =head2 Creating GnuPG::PublicKey Objects
 
@@ -1200,6 +1204,18 @@ The following setup can be done before any of the following examples:
   # no wait is required this time; it's handled internally
   # since the entire call is encapsulated
 
+=head2 Custom GnuPG call
+
+  # assuming $handles is a GnuPG::Handles object
+  my $pid = $gnupg->wrap_call
+    ( commands     => [ qw( --list-packets ) ],
+      command_args => [ qw( test/key.1.asc ) ],
+      handles      => $handles,
+    );
+    
+    my @out = <$handles->stdout()>;
+    waitpid $pid, 0;
+
 
 =head1 FAQ
 
@@ -1269,7 +1285,7 @@ L<perlipc/"Bidirectional Communication with Another Process">
 
 =head1 AUTHOR
 
-Frank J. Tobin, ftobin@uiuc.edu
+Frank J. Tobin, ftobin@cpan.org
 
 =head1 PACKAGE UPDATES
 
